# Generated by roxygen2: do not edit by hand

export(asciify_file)
export(asciify_pkg)
export(asciify_r_source)
export(audit_ascii)
export(audit_check)
export(audit_citation)
export(audit_dataset_doc)
export(audit_description)
export(audit_dontrun)
export(audit_downloads)
export(audit_globals)
export(audit_tags)
export(audit_userspace)
export(check_as_cran)
export(check_clean_userspace)
export(check_n_covr)
export(create_example_pkg)
export(find_missing_tags)
export(find_nonascii_files)
export(find_nonascii_tokens)
export(fix_ascii)
export(fix_dataset_doc)
export(fix_globals)
export(get_data_info)
export(get_no_visible)
export(get_notes)
export(print_globals)
export(use_data_doc)
importFrom(dplyr,
  filter,
  first,
  group_by,
  if_else,
  left_join,
  mutate,
  n,
  pull,
  rename,
  select,
  summarise,
  tibble,
  ungroup
)
importFrom(glue,
  glue,
  glue_collapse
)
importFrom(lifecycle,deprecated)
importFrom(magrittr,"%>%")
importFrom(purrr,
  compact,
  keep,
  map,
  walk
)
importFrom(rcmdcheck,rcmdcheck)
importFrom(stringr,
  str_extract,
  str_extract_all
)
importFrom(utils,getFromNamespace)
