---
title: "No files left after check"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{no-files-left-after-check}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

```{r setup}
library(checkhelper)
```

<!-- WARNING - This vignette is generated by {fusen} from dev/flat_check_clean_userspace.Rmd: do not edit by hand -->

# Check that the user space is clean after checks

`r lifecycle::badge("experimental")`

Have you faced a note on CRAN about non-standard things in the check directory ?

```
Check: for non-standard things in the check directory
Result: NOTE
    Found the following files/directories:
     ‘extrapackage’ 
```

Maybe you do not understand where these files came from.  
Then, you can run `check_clean_userspace()` in your package directory to detect every files that you created during the check.  
They could be issued from examples, tests or vignettes: `check_clean_userspace()` will tell you.



```{r examples-check_clean_userspace, eval = FALSE}
#' \dontrun{
# This runs a check of the current package
all_files <- check_clean_userspace()
all_files
#' }
```

